@@ -54,10 +54,7 @@ class ArjunFacade:
 
 from arjuna.engine import Arjuna
 
-from arjuna.interact.gui.helpers import With, WithType
-from arjuna.interact.gui.helpers import GuiInteractionConfig, GuiDriverExtendedConfigBuilder
-from arjuna.interact.gui.helpers import Screen
-
+from arjuna.interact.gui.helpers import Attr, Point, Params, Formatter, Locator
 from arjuna.interact.gui.gom import WebApp, Page, Section, Widget, Dialog
 
 from arjuna.core.exceptions import *
@@ -73,6 +70,25 @@ from arjuna.engine.data.record import *
 from arjuna.engine.data.generator import Random, DataEntity, Locales
 from arjuna.engine.relation import *
 from arjuna.engine.fixture import *
-from arjuna.core.xml import xfinder
+from arjuna.core.xml import NodeLocator
 from arjuna.core.adv.types import ProcessedKeyDict
-from arjuna.engine.data.localizer import L
\ No newline at end of file
+from arjuna.core.json import Json
+
+L = Arjuna.get_localized_str
+C = Arjuna.get_config_value
+R = Arjuna.get_dataref_value
+
+class LogCall:
+
+    def __init__(self, ctype):
+        self.__ctype = ctype.lower()
+    
+    def __call__(self, msg, *args, **kwargs):
+        from arjuna.core.audit import Stack
+        return getattr(Arjuna.get_logger(), self.__ctype)(msg, *args, extra={'invoker': Stack.get_invoker()}, **kwargs)
+
+log_debug = LogCall("debug")
+log_info = LogCall("info")
+log_warning = LogCall("warning")
+log_error = LogCall("error")
+log_fatal = LogCall("fatal")
\ No newline at end of file
