@@ -44,10 +44,8 @@ class ArjunaSingleton:
     def __init__(self):
         self.__project_root_dir = None
         self.__test_session = None
-        self.__run_context = None
         self.__ref_config = None
-        self.__context_map = dict()
-        self.__default_context_name = "default_context"
+        self.__config_map = dict()
         self.__run_id = None
 
         # From central config
@@ -61,7 +59,6 @@ class ArjunaSingleton:
         self.dl = None
         self.log_file_discovery_info = False
         self.__data_references = None
-        self.central_conf = None
         self.__console = None
         self.__logger = None
         from arjuna.engine.data.store import DataStore
@@ -75,7 +72,7 @@ class ArjunaSingleton:
         if not os.path.exists(d):
             os.makedirs(d)
 
-    def init(self, project_root_dir, cli_config, run_id, *, static_rid):
+    def init(self, project_root_dir, cli_config, run_id, *, static_rid, run_conf):
         from arjuna.configure.impl.processor import ConfigCreator
         ConfigCreator.init()
         self.__project_root_dir = project_root_dir
@@ -87,22 +84,20 @@ class ArjunaSingleton:
         if not static_rid:
             prefix = "{}-".format(datetime.datetime.now().strftime("%Y.%m.%d-%H.%M.%S.%f")[:-3])
         run_id = "{}{}".format(prefix, run_id)
-        self.__ref_config = self.__test_session.init(project_root_dir, cli_config, run_id)
+        self.__ref_config = self.__test_session.init(project_root_dir, cli_config, run_id, run_conf)
 
         from arjuna.core.enums import ArjunaOption
-        self.__create_dir_if_doesnot_exist(self.__ref_config.arjuna_options.value(ArjunaOption.PROJECT_RUN_REPORT_DIR))
-        self.__create_dir_if_doesnot_exist(self.__ref_config.arjuna_options.value(ArjunaOption.PROJECT_RUN_REPORT_XML_DIR))
-        self.__create_dir_if_doesnot_exist(self.__ref_config.arjuna_options.value(ArjunaOption.PROJECT_RUN_REPORT_HTML_DIR))
-        self.__create_dir_if_doesnot_exist(self.__ref_config.arjuna_options.value(ArjunaOption.PROJECT_RUN_LOG_DIR))
-        self.__create_dir_if_doesnot_exist(self.__ref_config.arjuna_options.value(ArjunaOption.PROJECT_RUN_SCREENSHOTS_DIR))
+        self.__create_dir_if_doesnot_exist(self.__ref_config.value(ArjunaOption.REPORT_DIR))
+        self.__create_dir_if_doesnot_exist(self.__ref_config.value(ArjunaOption.REPORT_XML_DIR))
+        self.__create_dir_if_doesnot_exist(self.__ref_config.value(ArjunaOption.REPORT_HTML_DIR))
+        self.__create_dir_if_doesnot_exist(self.__ref_config.value(ArjunaOption.LOG_DIR))
+        self.__create_dir_if_doesnot_exist(self.__ref_config.value(ArjunaOption.SCREENSHOTS_DIR))
 
-        dl = logging.getLevelName(self.__ref_config.arjuna_options.value(ArjunaOption.LOG_CONSOLE_LEVEL).name) # logging.getLevelName(
+        dl = logging.getLevelName(self.__ref_config.value(ArjunaOption.LOG_CONSOLE_LEVEL).name) # logging.getLevelName(
 
         self.__init_logger(dl)
         self.__load_console(dl, self.logger)
 
-        self.__run_context = self.create_test_context(self.__default_context_name)
-
         # Load data references
         from arjuna.engine.data.factory import DataReference
         self.__data_references = DataReference.load_all(self.__ref_config)
@@ -111,7 +106,16 @@ class ArjunaSingleton:
         from arjuna.engine.data.localizer import Localizer
         self.__localizer = Localizer.load_all(self.__ref_config)
 
-        return self.__run_context
+        from arjuna.core.yaml import YamlFile
+        from arjuna.interact.gui.auto.finder.withx import WithX
+        fpath = self.ref_config.value(ArjunaOption.GUIAUTO_WITHX_YAML)
+        self.__common_withx_ref = WithX(YamlFile(fpath).as_map())
+
+        return self.ref_config
+
+    @property
+    def withx_ref(self):
+        return self.__common_withx_ref
 
     @property
     def data_references(self):
@@ -133,89 +137,62 @@ class ArjunaSingleton:
     def data_store(self):
         return self.__data_store
 
-    @classmethod
-    def get_test_session(cls):
-        return cls.__SESSION
+    @property
+    def test_session(self):
+        return self.__test_session
 
-    @classmethod
-    def has_configuration(cls, config_name):
-        return config_name.upper() in cls.thread_map
-
-    @classmethod
-    def has_property(cls, config_name, path):
-        return cls.has_configuration(config_name) and path.upper() in cls.thread_map[config_name]
-
-    @classmethod
-    def merge_configuration(cls, source_config_name, target_config_name):
-        if cls.has_configuration(source_config_name):
-            if cls.has_configuration(target_config_name):
-                cls.thread_map[target_config_name.upper()] = cls.thread_map[source_config_name].clone()
+    def get_config_value(self, name, config=None):
+        config = config
+        query = name
+        if config is None:
+            if type(name) is str:
+                if name.find('.') != -1:
+                    conf, query = name.split(".", 1)
+                    if self.has_config(conf):
+                        config = self.get_config(conf)
+                    else:
+                        config = self.ref_config
+                        query = name
+                else:
+                    config = self.ref_config
+                    query = name
             else:
-                cls.register_new_configuration(target_config_name.upper())
-                cls.thread_map[target_config_name.upper()] = cls.thread_map[source_config_name.upper()].clone()
+                config = self.ref_config
+                query = name
         else:
-            raise Exception("No source configuration found for name: %s".format(source_config_name))
+            if type(config) is str:
+                config = self.get_config(config)
 
-    @classmethod
-    def register_new_configuration(cls, config_name):
-        cls.thread_map[config_name.upper()] = {}
-
-    @classmethod
-    def update_thread_config(cls, config_name, config):
-        cls.thread_map[config_name].clone_add(config)
-
-    @classmethod
-    def value(cls, prop_name):
-        # uc_prop_name = None
-        # if type(prop_name) is not str:
-        #     prop_name = self.__get_prop_path_for_enum(prop_name).upper()
-        uc_prop_name = prop_name.upper()
-        tname = thread_utils.get_current_thread_name()
-        if tname in cls.thread_map and uc_prop_name in cls.thread_map[tname]:
-            return cls.thread_map[tname][uc_prop_name].value
-        elif uc_prop_name in cls.arjuna_options:
-            return cls.arjuna_options[uc_prop_name].value
-        else:
-            raise Exception("No property configred for name: {}".format(prop_name))
-
-    @classmethod
-    def get_configured_name(self, section_name, internal_name):
-        return self.strings_manager.get_configured_name(section_name, internal_name)
-
-    @classmethod
-    def get_problem_text(self, problem_code):
-        return self.strings_manager.get_problem_text(problem_code)
-
-    @classmethod
-    def get_info_message_text(self, code):
-        return self.strings_manager.get_info_message_text(code)
-
-    @classmethod
-    def clone_evars(self):
-        return copy.deepcopy(self.exec_var_map)
-
-    @classmethod
-    def clone_user_options(self):
-        return copy.deepcopy(self.user_options)
+        return config.value(query)
 
     def __init_logger(self, dl):
+
+        class InvokerFilter(logging.Filter):
+
+            def filter(self, record):
+                if not hasattr(record, "invoker"):
+                    record.invoker = '<no_trace>'
+                return True
+
         from arjuna.core.enums import ArjunaOption
-        log_dir = self.__ref_config.arjuna_options.value(ArjunaOption.PROJECT_RUN_LOG_DIR)
+        log_dir = self.__ref_config.value(ArjunaOption.LOG_DIR)
         if not os.path.isdir(log_dir):
             os.makedirs(log_dir)
-        fl = logging.getLevelName(self.__ref_config.arjuna_options.value(ArjunaOption.LOG_FILE_LEVEL).name)
+        fl = logging.getLevelName(self.__ref_config.value(ArjunaOption.LOG_FILE_LEVEL).name)
         fname = "arjuna.log"
         lpath = os.path.join(log_dir, fname)
 
         logger = logging.getLogger("arjuna")
+        logger.addFilter(InvokerFilter())
         logger.setLevel(logging.DEBUG)
         ch = logging.StreamHandler(sys.stdout)
         ch.flush = sys.stdout.flush
         ch.setLevel(dl)
         fh = logging.FileHandler(lpath, "w", 'utf-8')
         fh.setLevel(fl)
-        f_fmt = logging.Formatter(u'[%(levelname)5s]\t%(asctime)s\t%(pathname)s::%(module)s.%(funcName)s:%(lineno)d\t%(message)s')
-        c_fmt = logging.Formatter(u'[%(levelname)5s]\t%(message)s')
+        #f_fmt = logging.Formatter(u'[%(levelname)5s]\t%(asctime)s\t%(pathname)s::%(module)s.%(funcName)s:%(lineno)d\t%(message)s')
+        f_fmt = logging.Formatter(u'[%(levelname)7s]\t%(asctime)s\t%(invoker)s\t%(message)s')
+        c_fmt = logging.Formatter(u'[%(levelname)7s]\t%(message)s')
         ch.setFormatter(c_fmt)
         fh.setFormatter(f_fmt)
         logger.addHandler(ch)
@@ -357,24 +334,20 @@ class ArjunaSingleton:
             display_padded_key_value_exception_trace = display_multiline_key_value
         self.__console = __console()
 
-    @property
-    def run_context(self):
-        return self.__run_context
-
     @property
     def ref_config(self):
         return self.__ref_config
 
-    def create_test_context(self, name):
-        '''
-            Creates test context object.
-            ?? Does it take central config??
-        '''
+    def get_config(self, name):
+        if not self.has_config(name):
+            raise Exception("There is no registered configuration for name: {}".format(name))
+        return self.__config_map[name.lower()]
 
-        from arjuna.configure.invoker.context import RunContext
-        context = RunContext(self.__test_session, name)
-        self.__context_map[name] = context
-        return context
+    def register_config(self, config):
+        self.__config_map[config.name.lower()] = config
+
+    def has_config(self, name):
+        return name.lower() in self.__config_map
 
 class Arjuna:
     '''
@@ -386,7 +359,7 @@ class Arjuna:
     LOGGER = None
 
     @classmethod
-    def init(cls, project_root_dir, cli_config=None, run_id=None, *, static_rid=False):
+    def init(cls, project_root_dir, cli_config=None, run_id=None, *, static_rid=False, run_conf=None):
         '''
             Returns reference test context which contains reference configuration.
             This reference test context merges central conf, project conf and central CLI options.
@@ -394,7 +367,7 @@ class Arjuna:
             You can also provide an alternative root directory for test project.
         '''
         cls.ARJUNA_SINGLETON = ArjunaSingleton()
-        return cls.ARJUNA_SINGLETON.init(project_root_dir, cli_config, run_id, static_rid=static_rid)
+        return cls.ARJUNA_SINGLETON.init(project_root_dir, cli_config, run_id, static_rid=static_rid, run_conf=run_conf)
 
     @classmethod
     def get_logger(cls):
@@ -411,18 +384,38 @@ class Arjuna:
         return cls.ARJUNA_SINGLETON.console
 
     @classmethod
-    def get_run_context(cls):
-        '''
-            Returns the run context.
-        '''
-        return cls.ARJUNA_SINGLETON.run_context
+    def register_config(cls, config):
+        cls.ARJUNA_SINGLETON.register_config(config)
 
     @classmethod
-    def get_ref_config(cls):
+    def has_config(cls, name):
+        return cls.ARJUNA_SINGLETON.has_config(name)
+
+    @classmethod
+    def get_config(cls, name=None):
         '''
             Returns the reference configuration.
         '''
-        return cls.ARJUNA_SINGLETON.ref_config
+        if name is None:
+            return cls.ARJUNA_SINGLETON.ref_config
+        else:
+            return cls.ARJUNA_SINGLETON.get_config(name)
+
+    @classmethod
+    def get_config_value(cls, name, config=None):
+        '''
+            Returns the reference configuration.
+        '''
+        return cls.ARJUNA_SINGLETON.get_config_value(name, config)
+
+    @classmethod
+    def get_dataref_value(cls, name, *, bucket=None, context=None):
+        '''
+            Returns the data reference value for a given context.
+        '''
+        from arjuna.engine.data.reference import R
+        return R(name, bucket=bucket, context=context)
+
 
     @classmethod
     def get_gui_mgr(cls):
@@ -431,65 +424,26 @@ class Arjuna:
         '''
         return cls.ARJUNA_SINGLETON.gui_mgr
 
-    @classmethod
-    def get_data_references(cls):
-        return cls.ARJUNA_SINGLETON.data_references
-
     @classmethod
     def get_localizer(cls):
         return cls.ARJUNA_SINGLETON.localizer
 
     @classmethod
     def get_data_ref(cls, name):
-        return cls.get_data_references[name]
+        return cls.ARJUNA_SINGLETON.data_references[name]
 
     @classmethod
-    def get_ref_arjuna_option_value(cls, option):
-        return cls.get_central_config().get_ref_arjuna_option_value(option)
-
-    @classmethod
-    def get_ref_user_option_value(cls, option):
-        return cls.get_central_config().get_ref_user_option_value(option) 
+    def get_localized_str(cls, in_str, *, locale=None, bucket=None, strict=None):
+        from arjuna.engine.data.localizer import L
+        return L(in_str, locale=locale, bucket=bucket, strict=strict)
 
     @classmethod
     def get_data_store(cls):
         return cls.ARJUNA_SINGLETON.data_store
 
-    @staticmethod
-    def get_test_context(name):
-        '''
-            Returns test context for a given name (case-insensitive).
-        '''
-        pass
-
-    @staticmethod
-    def register_test_context(context):
-        '''
-            Registers a test context object.
-        '''
-        pass    
-
     @classmethod
-    def create_test_context(cls, name):
-        '''
-            Creates test context object.
-            ?? Does it take central config??
-        '''
-        return cls.ARJUNA_SINGLETON.create_test_context(name)
-
-    @staticmethod
-    def get_root_dir(context):
-        '''
-            Returns root directory of test project.
-        '''
-        pass
-
-    @staticmethod
-    def create_datasource_builder():
-        '''
-            Creates and returns DataSourceBuilder object.
-        '''
-        pass
+    def get_withx_ref(cls):
+        return cls.ARJUNA_SINGLETON.withx_ref
 
     @staticmethod
     def exit():
