@@ -28,22 +28,30 @@ class ContextualDataReference(metaclass=abc.ABCMeta):
     def __init__(self):
         self.map = {}
 
-    @abc.abstractmethod
-    def record_for(self, context):
-        pass
-
     def update(self, data_reference):
         for context, record in data_reference.map.items():
             if context not in self.map:
                 self.map[context] = CIStringDict()
             self.map[context].update(record.named_values)
 
+    def update_from_dict(self, context, map):
+        if context not in self.map:
+            self.map[context] = dict()
+        self.map[context].update(map)
+
     def record_for(self, context):
         if context.lower() in self.map:
             return self.map[context.lower()]
         else:
             raise Exception("Context key {} not found in data reference: {}.".format(context, self.__class__.__name__))
 
+    def __str__(self):
+        return str({k: str(v) for k,v in self.map.items()})
+
+    def enumerate(self):
+        for k,v in self.map.items():
+            print(k, "::", type(v), str(v))
+
 class __ExcelDataReference(ContextualDataReference):
     def __init__(self, path):
         super().__init__()
@@ -103,3 +111,40 @@ class ExcelColumnDataReference(__ExcelDataReference):
         self.reader.close()
         for context, kv in cmap.items():
             self.map[context.lower()] = DataRecord(**kv)
+
+def R(query, *, bucket=None, context=None):
+    from arjuna import Arjuna, ArjunaOption
+    bucket = bucket
+    context = context
+    query = query
+
+    if bucket is not None:
+        bucket = bucket.lower()
+        if context is not None:
+            context = context.lower()
+            query = query.lower()
+        else:
+            if query.find('.') != -1:
+                context, query = query.split('.', 1)
+                context = context.lower()
+                query = query.lower()
+            else:
+                raise Exception("DataRefError: The query must specify context using dot notation when not passed as argument.")
+    else:
+        if context is not None:
+            raise Exception("bucket must be provided if context arg is passed.")
+        else:
+            if query.find('.') != -1:
+                bucket, context, query = query.split('.', 2)
+                bucket = bucket.lower()
+                context = context.lower()
+                query = query.lower()
+            else:
+                raise Exception("DataRefError: The query must specify bucket and context using dot notation when these are not passed as arguments.")           
+
+    try:
+        return Arjuna.get_data_ref(bucket).record_for(context)[query]
+    except Exception as e:
+        import traceback
+        raise Exception("Error in retrieving reference value for: {} in {} data reference. {}. {}".format(in_str, bucket, traceback.format_exc()))
+
