@@ -40,8 +40,8 @@ class GuiAutomator(ElementContainer,Dispatchable):
         self.__econfig = ext_config
         self.__create_screenshots_dir()
         self.__main_window = None
-        self.__in_slomo = config.arjuna_options.value(ArjunaOption.GUIAUTO_SLOMO_ON)
-        self.__slomo_interval = config.arjuna_options.value(ArjunaOption.GUIAUTO_SLOMO_INTERVAL)
+        self.__in_slomo = config.value(ArjunaOption.GUIAUTO_SLOMO_ON)
+        self.__slomo_interval = config.value(ArjunaOption.GUIAUTO_SLOMO_INTERVAL)
 
         from .webalert_handler import WebAlertHandler
         from .automator_conditions import GuiAutomatorConditions
@@ -50,7 +50,7 @@ class GuiAutomator(ElementContainer,Dispatchable):
         self.__conditions_handler = GuiAutomatorConditions(self)
         self.__view_handler = ViewContextHandler(self)
         self.__browser = None
-        self.__screenshots_dir = config.arjuna_options.value(ArjunaOption.PROJECT_RUN_SCREENSHOTS_DIR)
+        self.__screenshots_dir = config.value(ArjunaOption.SCREENSHOTS_DIR)
 
         self.__source_parser = None
 
@@ -78,11 +78,6 @@ class GuiAutomator(ElementContainer,Dispatchable):
     def get_source_from_remote(self):
         return self.dispatcher.get_source()
 
-    def load_source_parser(self):
-        raw_source = self.get_source_from_remote()
-        self.__source_parser = ElementXMLSourceParser(raw_source, root_element="html")
-        self.__source_parser.load()
-
     # def create_dispatcher(self):
     #     self._set_dispatcher(self.dispatcher_creator.create_gui_automator_dispatcher(self.config, self.setu_id))
 
@@ -104,22 +99,22 @@ class GuiAutomator(ElementContainer,Dispatchable):
         return self.__main_window
 
     def child_window(self, lmd):
-        return self.main_window.child_window(lmd)
+        return self.get_main_window().get_child_window(lmd)
 
     @property
     def latest_child_window(self):
-        return self.main_window.latest_child_window
+        return self.get_main_window().get_latest_child_window()
 
     def close_all_child_windows(self):
         self.main_window.close_all_child_windows()
 
-    def dom_root(self, gui):
+    def get_dom_root(self, gui):
         from arjuna.interact.gui.auto.component.frame import DomRoot
         return DomRoot(gui)
 
-    def frame(self, gui, lmd, iconfig=None):
+    def get_frame(self, gui, lmd, iconfig=None):
         return self.dom_root(gui).frame(lmd, iconfig=iconfig)
-        
+
     @property
     def alert_handler(self):
         return self.__alert_handler
@@ -133,7 +128,7 @@ class GuiAutomator(ElementContainer,Dispatchable):
         return self.__conditions_handler
 
     def __create_screenshots_dir(self):
-        sdir = self.config.arjuna_options.value(ArjunaOption.PROJECT_RUN_SCREENSHOTS_DIR)
+        sdir = self.config.value(ArjunaOption.SCREENSHOTS_DIR)
         if not os.path.isdir(sdir):
             os.makedirs(sdir)
 
@@ -151,8 +146,6 @@ class GuiAutomator(ElementContainer,Dispatchable):
         from .browser import Browser
         self.__browser = Browser(self)
 
-        self.load_source_parser()
-
     def quit(self):
         self.dispatcher.quit()
 
@@ -189,8 +182,11 @@ class GuiAutomator(ElementContainer,Dispatchable):
         self.main_window.focus()
 
     @property
-    def source(self): #, reload=True):
-        return self.__source_parser
+    def source(self):
+        raw_source = self.get_source_from_remote()
+        source_parser = ElementXMLSourceParser(raw_source, root_element="html")
+        source_parser.load()
+        return source_parser
 
     def perform_action_chain(self, single_action_chain):
         from arjuna.interact.gui.auto.automator.actions import SingleActionChain
@@ -208,31 +204,31 @@ class GuiAutomator(ElementContainer,Dispatchable):
 
     #### Element Finding
 
-    def element(self, gui, lmd, iconfig=None, max_wait_time=None):
+    def _element(self, gui, lmd, iconfig=None, max_wait_time=None):
         from arjuna.interact.gui.auto.element.guielement import GuiElement
         gui_element = GuiElement(gui, lmd, iconfig=iconfig) 
         self.load_element(gui_element, max_wait_time=max_wait_time)
         return gui_element
 
-    element_with_lmd = element
+    element_with_lmd = _element
 
-    def multi_element(self, gui, lmd, iconfig=None, max_wait_time=None):
+    def _multi_element(self, gui, lmd, iconfig=None, max_wait_time=None):
         from arjuna.interact.gui.auto.element.multielement import GuiMultiElement
         m_guielement = GuiMultiElement(gui, lmd, iconfig=iconfig)
         self.load_multielement(m_guielement, max_wait_time=max_wait_time)
         return m_guielement
 
-    multi_element_with_lmd = multi_element
+    multi_element_with_lmd = _multi_element
 
-    def dropdown(self, gui, lmd, option_container_lmd=None, option_lmd=None, iconfig=None):
+    def _dropdown(self, gui, lmd, option_container_lmd=None, option_lmd=None, iconfig=None):
         from arjuna.interact.gui.auto.component.dropdown import GuiWebSelect
         return GuiWebSelect(gui, lmd, option_container_lmd=option_container_lmd, option_lmd=option_lmd, iconfig=iconfig)
 
-    def radio_group(self, gui, lmd, iconfig=None):
+    def _radio_group(self, gui, lmd, iconfig=None):
         from arjuna.interact.gui.auto.component.radio_group import GuiWebRadioGroup
         return GuiWebRadioGroup(gui, lmd)
 
-    def tab_group(self, gui, lmd, *, tab_header_lmd, content_relation_attr, content_relation_type, iconfig=None):
+    def _tab_group(self, gui, lmd, *, tab_header_lmd, content_relation_attr, content_relation_type, iconfig=None):
         from arjuna.interact.gui.auto.component.tabs import TabGroup
         return TabGroup(
             gui, 
