@@ -25,10 +25,6 @@ class GuiAutomatorConditions:
     def __init__(self, automator):
         self.__automator = automator
 
-    @property
-    def automator(self):
-        return self.__automator
-
     def AlertIsPresent(self):
-        caller = DynamicCaller(self.automator.alert_handler.is_alert_present)
+        caller = DynamicCaller(self.__automator.get_alert_handler().is_alert_present)
         return BooleanCondition(caller, True)
\ No newline at end of file
