@@ -18,7 +18,6 @@ limitations under the License.
 '''
 
 import traceback
-from arjuna.interact.gui.auto.element.guielement import GuiElement
 from arjuna.core.enums import ArjunaOption
 from arjuna.interact.gui.auto.finder.emd import SimpleGuiElementMetaData
 
@@ -50,7 +49,7 @@ class BasicWindow:
 
     @property
     def max_wait_time(self):
-        return self.automator.config.guiauto_max_wait
+        return self.__automator.config.guiauto_max_wait
 
     @property
     def app(self):
@@ -70,26 +69,26 @@ class BasicWindow:
 
     @property
     def title(self):
-        return self.automator.dispatcher.get_current_window_title()
+        return self.__automator.dispatcher.get_current_window_title()
 
     @property
     def size(self):
-        return self.automator.dispatcher.get_current_window_size()
+        return self.__automator.dispatcher.get_current_window_size()
 
     def _set_handle(self, handle):
         self.__window_handle = handle
 
     def focus(self):
-        self.automator.dispatcher.focus_on_window(self.handle)
+        self.__automator.dispatcher.focus_on_window(self.handle)
 
     def is_main_window(self):
         return False
 
     def set_window_size(self, width, height):
-        self.automator.dispatcher.set_current_window_size(width, height)
+        self.__automator.dispatcher.set_current_window_size(width, height)
 
     def maximize(self):
-        self.automator.dispatcher.maximize_current_window()
+        self.__automator.dispatcher.maximize_current_window()
 
 class MainWindow(BasicWindow):
 
@@ -106,13 +105,13 @@ class MainWindow(BasicWindow):
         return self.__conditions
 
     def get_all_child_window_handles(self):
-        handles = self.automator.dispatcher.get_all_window_handles()
+        handles = self.__automator.dispatcher.get_all_window_handles()
         handles = [handle for handle in handles if handle != self.handle]
         new_handles = []
         for handle in handles:
             if handle != self.handle:
                 if handle not in self.__all_child_windows:
-                    cwin = ChildWindow(self.app, self.automator, self, handle)
+                    cwin = ChildWindow(self.app, self.__automator, self, handle)
                     self.__all_child_windows[handle] = cwin
                     new_handles.append(handle)
         return handles, new_handles
@@ -147,7 +146,7 @@ class MainWindow(BasicWindow):
         return self.automator.dispatcher.get_current_window_handle()
 
     def child_window(self, locator_meta_data):
-        return self.conditions.ChildWindowIsPresent(locator_meta_data).wait(max_wait_time=self.max_wait_time)
+        return self.get_conditions().ChildWindowIsPresent(locator_meta_data).wait(max_wait_time=self.max_wait_time)
 
     def _find_child_window(self, locator_meta_data):
         all_child_handles, _ = self.get_all_child_window_handles()
@@ -168,7 +167,7 @@ class MainWindow(BasicWindow):
                             # The element for window is created in the context of an app.
                             # Need to verify this logic.
                             # and its impact on POM.
-                            contained_element = self.automator.element(self.app,emd, max_wait_time=0.5)
+                            contained_element = self.__automator.element(self.app,emd, max_wait_time=0.5)
                             # contained_element.find()
                             return cwin
                         except WaitableError as f:
@@ -181,9 +180,9 @@ class MainWindow(BasicWindow):
     def __resize_window_as_per_config(self):
         # Resize window
         config = self.config
-        browser_width = config.arjuna_options.value(ArjunaOption.BROWSER_DIM_WIDTH)
-        browser_height = config.arjuna_options.value(ArjunaOption.BROWSER_DIM_HEIGHT)
-        should_maximize = config.arjuna_options.value(ArjunaOption.BROWSER_MAXIMIZE)
+        browser_width = config.value(ArjunaOption.BROWSER_DIM_WIDTH)
+        browser_height = config.value(ArjunaOption.BROWSER_DIM_HEIGHT)
+        should_maximize = config.value(ArjunaOption.BROWSER_MAXIMIZE)
 
         if config.is_arjuna_option_not_set(ArjunaOption.BROWSER_DIM_WIDTH) and config.is_arjuna_option_not_set(ArjunaOption.BROWSER_DIM_HEIGHT):
             if should_maximize:
