@@ -31,7 +31,7 @@ from arjuna.interact.gui.auto.element.guielement import GuiElement
 from arjuna.interact.gui.auto.source.parser import *
 from arjuna.engine.asserter import AsserterMixIn
 
-class _GuiPartialElement(GuiElement):
+class GuiPartialElement(GuiElement):
 
     def __init__(self, gui, multi_element, index: int, dispatcher_element, iconfig=None):
         super().__init__(gui, multi_element.lmd, iconfig=iconfig)
@@ -72,28 +72,21 @@ class GuiMultiElement(AsserterMixIn, Locatable,Dispatchable,Configurable):
         for instance in self.__elements:
             instance.configure(elem_config)
 
-    # def find(self):
-    #     self.parent_container.find_multielement(self)
-    #     self.__load_source_parser()
-
-    # #Override
-    # def find_if_not_found(self):
-    #     if not self.is_found():
-    #         self.find()
-
     def load_source_parser(self):
         self.__source_parser = MultiElementSource(self.elements)
-        # self.__source_parser.load(self.__elements)
 
     def __getitem__(self, index):
-        # self.find_if_not_found()
         return self.__elements[index]
 
     @property
     def size(self):
-        # self.find_if_not_found()
         return len(self.__elements)
 
+    length = size
+
+    def __len__(self):
+        return self.size
+
     def assert_size(self, size, obj_name, msg=None):
         self.asserter.assert_equal(self.size, size, msg="{} should have exactly {} elements, but was found to have {} elements.".format(obj_name, size, self.size, self.asserter.format_msg(msg)))
 
@@ -114,18 +107,13 @@ class GuiMultiElement(AsserterMixIn, Locatable,Dispatchable,Configurable):
         # The logic ignores stale elements 
         for i in range(count):
             try:
-                e = _GuiPartialElement(self.gui, self, i, self.dispatcher.get_element_at_index(i), iconfig=self.settings)
+                e = GuiPartialElement(self.gui, self, i, self.dispatcher.get_element_at_index(i), iconfig=self.settings)
                 self.__elements.append(e)
             except StaleElementReferenceException as e:
                 pass
 
-    length = size
-
-
-
     @property
     def random_element(self):
-        # self.find_if_not_found()
         return self[random.randint(0, self.size-1)]
 
     @property
@@ -134,26 +122,21 @@ class GuiMultiElement(AsserterMixIn, Locatable,Dispatchable,Configurable):
 
     @property
     def last_element(self):
-        return self[self.length-1]
+        return self[len(self)-1]
 
     def get_element_at_ordinal(self, ordinal):
-        # self.find_if_not_found()
         return self.__elements[ordinal-1]
 
-    def get_instance_by_visible_text(self, text):
+    def get_element_by_visible_text(self, text):
         texts = self.__get_all_texts()
         first_index = self.__find_first_text_index(texts, text)
         return self[first_index]
 
-    def get_instance_by_value(self, value):
+    def get_element_by_value(self, value):
         values = self.__get_all_values()
         first_index = self.__find_first_value_index(values, value)
         return self[first_index]
 
-    def wait_until_visible(self):
-        self.find_if_not_found()
-        # Should the logic be keptin Setu itself for this????
-
     def __return_attr_values(self, response):
         if "data" in response and "attrValues" in response["data"]:
             return response["data"]["attrValues"]
@@ -166,7 +149,6 @@ class GuiMultiElement(AsserterMixIn, Locatable,Dispatchable,Configurable):
     # getting index attribute when it does not exist retursn value attribute.
     # So, not going the Selenium way. Setu would treat index as computer counting.
     def has_index_selected(self, index):
-        # self.find_if_not_found()
         return self[index].is_selected()
 
     # Ordinal is human counting
@@ -180,7 +162,6 @@ class GuiMultiElement(AsserterMixIn, Locatable,Dispatchable,Configurable):
             return -1
 
     def __get_all_texts(self):
-        # self.find_if_not_found()
         self.load_source_parser()
         texts = self.__source_parser.get_text_contents()
         return texts
@@ -192,7 +173,6 @@ class GuiMultiElement(AsserterMixIn, Locatable,Dispatchable,Configurable):
         return first_index
 
     def __get_all_values(self):
-        # self.find_if_not_found()
         self.load_source_parser()
         values = self.__source_parser.get_values()
         return values
@@ -204,7 +184,6 @@ class GuiMultiElement(AsserterMixIn, Locatable,Dispatchable,Configurable):
         return first_index
 
     def get_first_selected_instance(self):
-        # self.find_if_not_found()
         self.load_source_parser()
         booleans = self.are_selected()
         first_index = None
@@ -227,6 +206,7 @@ class GuiMultiElement(AsserterMixIn, Locatable,Dispatchable,Configurable):
     def filter(self):
         return ElementFilter(self)
 
+
 class ElementFilter:
 
     def __init__(self, gui_multi_element):
