@@ -1,3 +1,23 @@
+'''
+This file is a part of Arjuna
+Copyright 2015-2020 Rahul Verma
+
+Website: www.RahulVerma.net
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+  http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+'''
+
+
 from arjuna.interact.gui.dispatcher.driver.element_commands import DriverElementCommands
 from arjuna.interact.gui.dispatcher.driver.element_finder import ElementFinder
 from arjuna.interact.gui.dispatcher.driver.melement import MultiElement
@@ -31,7 +51,7 @@ class SeleniumDriverElementDispatcher:
     def find_multielement(self, with_type, with_value):
         web_elements = ElementFinder.find_elements(self.driver_element, with_type, with_value)
         melement = MultiElement([self.create_dispatcher(self.__driver_dispatcher, web_element) for web_element in web_elements])
-        return melement.get_instance_count(), melement
+        return melement.get_size(), melement
 
     @property
     def driver(self):
@@ -46,6 +66,12 @@ class SeleniumDriverElementDispatcher:
     def hover(self):
         self.__driver_dispatcher.hover_on_element(self)
 
+    def mouse_click(self):
+        self.__driver_dispatcher.mouse_click_on_element(self)
+
+    def scroll_to_view(self):
+        self.__driver_dispatcher.scroll_to_element(self)
+
     def clear_text(self):
         DriverElementCommands.clear_text(self.driver_element)
 
@@ -74,4 +100,7 @@ class SeleniumDriverElementDispatcher:
                 raise e
 
     def get_text_content(self):
-        return DriverElementCommands.get_text_content(self.driver_element)
\ No newline at end of file
+        return DriverElementCommands.get_text_content(self.driver_element)
+
+    def scroll_full_height(self):
+        self.__driver_dispatcher.execute_javascript("arguments[0].scrollBy(0, arguments[1].scrollHeight)", self.driver_element, self.driver_element)
\ No newline at end of file
