@@ -22,38 +22,41 @@ import abc
 import os
 from enum import Enum
 import unittest
+import functools
 
 from arjuna.interact.gui.auto.finder.emd import GuiElementMetaData
+from arjuna.interact.gui.helpers import Dictable
 
 from .guidef import *
+from .formatter import WithFormatter
 from arjuna.engine.asserter import AsserterMixIn
 
 from arjuna.core.poller.conditions import *
 from arjuna.core.poller.caller import *
-from arjuna.core.exceptions import WaitableError, GuiNotLoadedError, GuiNamespaceLoadingError
+from arjuna.core.exceptions import *
+from arjuna.interact.gui.gom.gns import GNS
 
 class GuiConditions:
 
     def __init__(self, gui):
         self.__gui = gui
 
-    @property
-    def gui(self):
-        return self.__gui
-
     def GuiReady(self):
-        caller = DynamicCaller(self.gui.validate_readiness)
+        caller = DynamicCaller(self.__gui.validate_readiness)
         return CommandCondition(caller)
 
 class Gui(AsserterMixIn):
 
-    def __init__(self, *, config=None, ext_config=None, label=None):
+    def __init__(self, *, gns_dir, config=None, ext_config=None, label=None):
         '''
             You can either provide automator.
         '''
         super().__init__()
         from arjuna import Arjuna
-        self.__config = config is not None and config or Arjuna.get_ref_config()
+        self.__config = config is not None and config or Arjuna.get_config()
+        from arjuna.core.enums import ArjunaOption
+        ns_root_dir = self.config.value(ArjunaOption.GUIAUTO_NAMESPACE_DIR)
+        self.__gns_dir = os.path.join(ns_root_dir, gns_dir)
         self.__econfig = ext_config
         self.__conditions = GuiConditions(self)
         if ext_config is None:
@@ -64,7 +67,10 @@ class Gui(AsserterMixIn):
             else:
                 self.__econfig = ext_config.config
         self.__label = label is not None and label or self.__class__.__name__
-        self.__externalized = False
+
+    @property
+    def gns_dir(self):
+        return self.__gns_dir
 
     @property
     def conditions(self):
@@ -93,11 +99,13 @@ class Gui(AsserterMixIn):
     def _load(self, *args, **kwargs):
         self.prepare(*args, **kwargs)
         try:
-            self.load_root_element()
+            self._load_root_element()
         except Exception as e:
             import traceback
             raise GuiNotLoadedError(self, "Root Element not Loaded. " + str(e) + "\n" + traceback.format_exc())
 
+        self._load_gns()
+
         try:
             self.load_anchor_element()
         except Exception as e:
@@ -125,37 +133,40 @@ class Gui(AsserterMixIn):
     def validate_readiness(self):
         pass
 
-    def load_root_element(self):
+    def _load_root_element(self):
         pass
 
     def load_anchor_element(self):
         pass
 
-    @property
-    def externalized(self):
-        return self.__externalized
-
-    def _set_externalized(self):
-        self.__externalized = True
-
 class AppContent(Gui):
 
-    def __init__(self, *args, automator, label=None, **kwargs):
-        super().__init__(config=automator.config, ext_config=automator.ext_config, label=label)
+    def __init__(self, *args, automator, label=None, gns_dir=None, gns_file_name=None, **kwargs):
         self.__app = automator.app
         self.__automator = automator
+        gns_dir = gns_dir and gns_dir or self.app.gns_dir
+        super().__init__(gns_dir=gns_dir, config=automator.config, ext_config=automator.ext_config, label=label)
+        gns_file_name = gns_file_name is not None and gns_file_name or "{}.yaml".format(self.label)
+        self.__def_file_path = os.path.join(self.gns_dir, gns_file_name)
+
         from arjuna import Arjuna
         self.__guimgr = Arjuna.get_gui_mgr()
         self.__guidef = None
-
         self.__gui_registered = False
-        self.__gns_file_name = None
-        self.__def_file_path = None
+        self._externalize()
+        self.__gns = None
+        
+    def _load_gns(self):
+        self.__gns = GNS(self, self.gui_def)
+
+    @property
+    def gns(self):
+        return self.__gns
 
     @property
     def app(self):
         return self.__app
-    
+
     @property
     def automator(self):
         return self.__automator
@@ -164,28 +175,15 @@ class AppContent(Gui):
     def gui_def(self):
         return self.__guidef
 
-    def externalize(self, gns_dir=None, gns_file_name=None):
-        self.__gns_file_name = gns_file_name is not None and gns_file_name or "{}.yaml".format(self.label)        
-        from arjuna.core.enums import ArjunaOption
-        gns_dir = gns_dir and gns_dir or self.app.gns_dir
-        if not gns_dir:
-            gns_dir = ""
-        ns_root_dir = self.config.arjuna_options.value(ArjunaOption.GUIAUTO_NAMESPACE_DIR)
-        
-        self.__def_file_path = os.path.join(ns_root_dir, gns_dir, self.gns_file_name)
+    def _externalize(self):
         try:
-            self.__guidef = GuiDef(self.__guimgr.name_store, self.automator, self.label, self.__def_file_path) # self.__guimgr.namespace_dir, 
+            self.__guidef = GuiDef(self.__guimgr.name_store, self.automator, self.label, self.def_file_path)
         except Exception as e:
             import traceback
             raise GuiNamespaceLoadingError(self, str(e) + traceback.format_exc())
 
         from arjuna import Arjuna
         Arjuna.get_logger().debug("Gui Namespace loading completed for {}.".format(self.label))
-        self._set_externalized()
-
-    @property
-    def gns_file_name(self):
-        return self.__gns_file_name
 
     @property
     def def_file_path(self):
@@ -194,63 +192,109 @@ class AppContent(Gui):
     def transit(self, page):
         pass
 
-    def convert_to_with_lmd(self, *raw_str_or_with_locators, nested_element=False):
-        from arjuna.interact.gui.helpers import With, WithType
-        out = []
-        for locator in raw_str_or_with_locators:
-            w = None
-            if isinstance(locator, With):
-                w = locator
-            elif type(locator) is str:
-                w = With.label(locator)
-            elif isinstance(locator, Enum):
-                w = With.label(locator.name)
-            else:
-                raise Exception("A With object or name of element is expected as argument.")
+    def convert_to_lmd(self, meta=None, **kwargs):
+        from arjuna import Arjuna
+        from arjuna.interact.gui.auto.finder._with import With
+        from arjuna.interact.gui.auto.finder.enums import WithType
+        with_list = []
+        for k,v in kwargs.items():
+            if k.upper() in WithType.__members__:
+                if isinstance(v, Dictable):
+                    v = v.as_dict()
+                with_list.append(getattr(With, k.lower())(v))
+            elif Arjuna.get_withx_ref().has_locator(k):
+                if isinstance(v, Dictable):
+                    v = v.as_dict()
+                    with_list.append(getattr(With, k.lower())(**v))
+                else:
+                    with_list.append(getattr(With, k.lower())(v))
+        if not with_list:
+            raise Exception("You must provide atleast one locator.")
+        from arjuna.interact.gui.auto.finder.emd import GuiElementMetaData
+        return GuiElementMetaData.create_lmd(*with_list, meta=meta)
 
-            if w.wtype == WithType.LABEL:
-                if isinstance(w.wvalue, Enum):
-                    w.wvalue = w.wvalue.name
-                out.extend(self.gui_def.convert_to_with(w))
-            else:
-                out.append(w)
-        lmd = GuiElementMetaData.create_lmd(*out)
-        return lmd
+    @property
+    def root_element(self):
+        return None
 
     @property
     def browser(self):
-        return self.impl_gui.browser
+        return self.automator.browser
 
-    def element(self, *str_or_with_locators, iconfig=None):
-        return self.automator.element(self, self.convert_to_with_lmd(*str_or_with_locators), iconfig=iconfig)
+    def format(self, **kwargs):
+        return WithFormatter(self, **kwargs)
 
-    def multi_element(self, *str_or_with_locators, iconfig=None):
-        return self.automator.multi_element(self, self.convert_to_with_lmd(*str_or_with_locators), iconfig=iconfig)
+    def convert_locator_to_emd(self, locator):
+        largs = locator.named_args
+        if largs is None:
+            largs = dict()
+        emd = self.convert_to_lmd({"template": locator.template}, **largs)
+        fargs = locator.fmt_args
+        if fargs is None:
+            fargs = dict()
+        fmt_emd = emd.create_formatted_emd(**fargs)
+        return fmt_emd 
 
-    def dropdown(self, *str_or_with_locators, option_container_locator=None, option_locator=None, iconfig=None):
-        return self.automator.dropdown(
+    def locate(self, locator):
+        from arjuna import log_debug
+        emd = self.convert_locator_to_emd(locator)
+        log_debug("Finding element with emd: {}.".format(emd))
+        try:
+            return getattr(self, "_" +  emd.meta.template.name.lower())(emd)
+        except ArjunaTimeoutError:
+            raise GuiElementNotPresentError(self, emd) 
+
+    def locate_element(self, *, template="element", fargs=None, **kwargs):
+        from arjuna.interact.gui.helpers import Locator
+        return self.locate(Locator(template=template, fmt_args=fargs, **kwargs))
+
+    element = locate_element
+
+    def multi_element(self, fargs=None, **kwargs):
+        return self.locate_element(template="multi_element", fargs=fargs, **kwargs)
+
+    def dropdown(self, fargs=None, **kwargs):
+        return self.locate_element(template="dropdown", fargs=fargs, **kwargs)
+
+    def radio_group(self, fargs=None, **kwargs):
+        return self.locate_element(template="radio_group", fargs=fargs, **kwargs)
+
+    def _element(self, lmd, iconfig=None):
+        return self.automator._element(self, lmd, iconfig=iconfig)
+
+    def _multi_element(self, lmd, iconfig=None):
+        return self.automator._multi_element(self, lmd, iconfig=iconfig)
+
+    def _dropdown(self, lmd, option_container_locator=None, option_locator=None, iconfig=None):
+        return self.automator._dropdown(
             self, 
-            self.convert_to_with_lmd(*str_or_with_locators),
+            lmd,
             option_container_lmd=option_container_locator and self.convert_to_with_lmd(option_container_locator) or None,
             option_lmd=option_locator and self.convert_to_with_lmd(option_locator) or None,
             iconfig=iconfig
         )
 
-    def radio_group(self, *str_or_with_locators, iconfig=None):
-        return self.automator.radio_group(self, self.convert_to_with_lmd(*str_or_with_locators), iconfig=iconfig)
+    def _radio_group(self, lmd, iconfig=None):
+        return self.automator._radio_group(self, lmd, iconfig=iconfig)
 
-    def tab_group(self, *str_or_with_locators, tab_header_locator, content_relation_attr, content_relation_type, iconfig=None):
-        return self.automator.tab_group(
-            self,
-            self.convert_to_with_lmd(*str_or_with_locators),
-            tab_header_lmd=self.convert_to_with_lmd(tab_header_locator),
-            content_relation_attr=content_relation_attr, 
-            content_relation_type=content_relation_type, 
-            iconfig=iconfig
-        )
+    def _wait_until_absent(self, emd):
+        try:
+            self.automator.wait_until_element_absent(emd)
+        except ArjunaTimeoutError:
+            raise GuiElementPresentError(self, emd)         
 
-    def wait_until_element_absent(self, *str_or_with_locators):
-        return self.automator.wait_until_element_absent(self.convert_to_with_lmd(*str_or_with_locators))
+    def wait_until_absent(self, *, fargs=None, **kwargs):
+        from arjuna.interact.gui.helpers import Locator
+        emd = self.convert_locator_to_emd(Locator(fmt_args=fargs, **kwargs))
+        self._wait_until_absent(emd)
+
+    def contains(self, *, fargs=None, **kwargs):
+        try:
+            self.element(fargs=fargs, **kwargs)
+        except GuiElementNotPresentError:
+            return False
+        else:
+            return True
 
     @property
     def dom_root(self):
@@ -281,10 +325,6 @@ class AppContent(Gui):
     def close_all_child_windows(self):
         self.automator.close_all_child_windows()
 
-    @property
-    def browser(self):
-        return self.automator.browser
-
     def set_slomo(self, on, interval=None):
         self.automator.set_slomo(on, interval)
 
@@ -298,16 +338,19 @@ class AppContent(Gui):
         self.browser.go_to_url(url)
 
     def load_anchor_element(self):
-        if self.externalized:
-            locators = self.gui_def.anchor_element_with_locators
+        label = self.gui_def.anchor_element_name
 
-            from arjuna import Arjuna
-            Arjuna.get_logger().debug("Loading State Element for {} widget. __state__ locators in GNS: {}.".format(
-                self.label,
-                GuiElementMetaData.locators_as_str(locators),
-            ))
+        from arjuna import Arjuna
+        Arjuna.get_logger().debug("Loading Anchor Element for {} Gui. anchor label in GNS: {}.".format(
+            self.label,
+            self.gui_def.anchor_element_name,
+        ))
 
-            if locators is not None:
-                self.element(*locators)
+        if label is not None:
+            getattr(self.gns, label)
+
+    @property
+    def source(self):
+        return self.automator.source
 
 
