@@ -20,8 +20,8 @@ limitations under the License.
 import os
 
 from .nsloader import GuiNamespaceLoaderFactory
-from arjuna.interact.gui.auto.finder.emd import SimpleGuiElementMetaData, GuiElementMetaData, Locator
-from arjuna.interact.gui.helpers import With
+from arjuna.interact.gui.auto.finder.emd import GuiElementMetaData
+from arjuna.interact.gui.auto.finder._with import With, Locator
 from arjuna.core.exceptions import GuiLabelNotPresentError
 
 class GuiDef:
@@ -57,16 +57,23 @@ class GuiDef:
     def config(self):
         return self.__config
 
+    @property
+    def is_empty(self):
+        return seff.__ns.is_empty()
+
     # def add_child(self, label, automator, file_def_path):
     #     self.__children.append(
     #         Gui(self.__name_store, self.__namespace_dir, label, self.__automator, file_def_path)
     # )
 
+    def get_emd(self, label):
+        return self.__ns.get_meta_data(label, self.__auto_context)
+
     def convert_to_lmd(self, *locators):
         final_locators = []
         for raw_locator in locators:
             if raw_locator.wtype.upper().strip() == "LABEL":
-                emd = self.__ns.get_meta_data(raw_locator.wvalue, self.__auto_context)
+                emd = self.get_emd(raw_locator.wvalue)
                 for loc in emd.raw_locators:
                     if not raw_locator.named_args:
                         final_locators.append(Locator(ltype=loc.ltype, lvalue=loc.lvalue), named_args={})
@@ -77,8 +84,6 @@ class GuiDef:
                     final_locators.append(Locator(ltype=raw_locator.wtype, lvalue=raw_locator.wvalue), named_args={})
                 else:
                     final_locators.append(Locator(ltype=raw_locator.ltype, lvalue=raw_locator.lvalue), named_args=raw_locator.named_args)
-        import sys
-        sys.exit(1)
         return GuiElementMetaData(final_locators)
 
     def __gns_locators_as_with_locators(self, label):
@@ -91,7 +96,7 @@ class GuiDef:
         return out
 
     def convert_to_with(self, locator):
-        from arjuna.interact.gui.helpers import With
+        from arjuna.interact.gui.auto.finder._with import With
         out_list = []
         impl_with = locator.as_impl_locator()
         for wobj in self.__gns_locators_as_with_locators(impl_with.wvalue):
@@ -103,18 +108,18 @@ class GuiDef:
         return out_list
 
     @property
-    def root_element_with_locators(self):
+    def root_element_name(self):
         try:
-            return self.__gns_locators_as_with_locators("__root__")
-        except GuiLabelNotPresentError:
+            return self.__ns.root_element_name
+        except KeyError:
             # Defining __root__ is optional for GNS files.
             return None
 
     @property
-    def anchor_element_with_locators(self):
+    def anchor_element_name(self):
         try:
-            return self.__gns_locators_as_with_locators("__anchor__")
-        except GuiLabelNotPresentError:
+            return self.__ns.anchor_element_name
+        except KeyError:
             # Defining __load__ is optional for GNS files.
             return None
 
