@@ -83,14 +83,16 @@ class MainCommand(Command):
         return self.parser.add_subparsers(title="Valid Commands", description="What do you want Arjuna to do?", dest='command')
 
     def convert_to_dict(self, args):
-        def format_value(v):
+        def format_value(k, v):
+            if k in {"ao", "uo"}:
+                return v
             if type(v) is list:
                 return ",".join([str(i) for i in v])
             else:
                 return v
         try:
             args = self.parser.parse_args(args[1:])
-            return {k:format_value(v) for k,v in vars(args).items()}
+            return {k:format_value(k,v) for k,v in vars(args).items()}
         except Exception as e:
             print("!!!Fatal Error!!!")
             print(e)
@@ -125,20 +127,23 @@ class CreateProject(Command):
 
     COMMON_DIRS_FILES = (
         (FileObjectType.DIR, "config"),
+        (FileObjectType.DIR, "config/env"),
         (FileObjectType.FILE, "config/project.conf"),
         (FileObjectType.DIR, "data"),
         (FileObjectType.DIR, "data/source"),
         (FileObjectType.DIR, "data/reference"),
         (FileObjectType.DIR, "data/reference/excel_column"),
         (FileObjectType.DIR, "data/reference/excel_row"),
-        (FileObjectType.DIR, "data/l10"),
-        (FileObjectType.DIR, "data/l10/excel"),
+        (FileObjectType.DIR, "l10n"),
+        (FileObjectType.DIR, "l10n/excel"),
         (FileObjectType.DIR, "guiauto"),
         (FileObjectType.DIR, "guiauto/driver"),
         (FileObjectType.DIR, "guiauto/driver/linux"),
         (FileObjectType.DIR, "guiauto/driver/mac"),
         (FileObjectType.DIR, "guiauto/driver/windows"),
         (FileObjectType.DIR, "guiauto/namespace"),
+        (FileObjectType.DIR, "guiauto/withx"),
+        (FileObjectType.DIR, "guiauto/withx/withx.yaml"),
         (FileObjectType.DIR, "report"),
         (FileObjectType.DIR, "script"),
         (FileObjectType.DIR, "test"),
@@ -181,7 +186,6 @@ class CreateProject(Command):
             parent.process(arg_dict)
         # from arjuna import ArjunaCore
         pdir = arg_dict['project.root.dir']
-        print(os.path.join(pdir, "config/project.conf"))
         if os.path.exists(os.path.join(pdir, "config/project.conf")):
             print("Arjuna project already exists at the specified location.")
             sys.exit(1)
@@ -200,17 +204,16 @@ class CreateProject(Command):
             f = open(get_proj_target_path("test/conftest.py"), "w")
             f.write(contents)
             f.close()
-            for d in [ "data/source", "data/l10/excel", "data/reference/excel_row", "data/reference/excel_column", "guiauto/namespace"]:
+            for d in [ "config/env", "data/source", "l10n/excel", "data/reference/excel_row", "data/reference/excel_column", "guiauto/namespace"]:
                 copy_file("../../res/placeholder.txt", d + "/placeholder.txt")
             for os_name in ["mac", "windows", "linux"]:
-                copy_file("../../res/placeholder.txt", "guiauto/driver/{}/driver.txt".format(os_name))
+                copy_file("../../res/placeholder.txt", "guiauto/driver/{}/placeholder.txt".format(os_name))
             for f in os.listdir(project_temp_dir):
                 try:
                     shutil.move(os.path.join(project_temp_dir, f), pdir)
                 except Exception as e:
                     print(e)
                     pass
-                
 
         print("Project {} successfully created at {}.".format(project_name, parent_dir))
 
@@ -232,14 +235,15 @@ class __RunCommand(Command):
         runid = arg_dict.pop("run.id")
         static_rid = arg_dict.pop("static.rid")
         self.dry_run = arg_dict.pop("dry_run")
+        self.run_conf = arg_dict.pop("run_conf")
 
-        Arjuna.init(project_root_dir, CliArgsConfig(arg_dict).as_map(), runid, static_rid=static_rid)
+        Arjuna.init(project_root_dir, CliArgsConfig(arg_dict).as_map(), runid, static_rid=static_rid, run_conf=self.run_conf)
 
         import sys
-        proj_dir = Arjuna.get_ref_config().arjuna_options.value(ArjunaOption.PROJECT_ROOT_DIR)
+        proj_dir = Arjuna.get_config().value(ArjunaOption.PROJECT_ROOT_DIR)
         sys.path.append(proj_dir + "/..")
 
-        py_3rdparty_dir = Arjuna.get_ref_config().arjuna_options.value(ArjunaOption.ARJUNA_EXTERNAL_IMPORTS_DIR)
+        py_3rdparty_dir = Arjuna.get_config().value(ArjunaOption.ARJUNA_EXTERNAL_IMPORTS_DIR)
         sys.path.append(py_3rdparty_dir)
 
 
