@@ -71,33 +71,20 @@ class RunParser(Parser):
         self.parser = argparse.ArgumentParser(add_help=False)
         self.parser.add_argument("-rid", "--runid", dest="run.id", type=partial(lname_check, "Run ID"), help = 'Alnum 3-30 length. Only lower case letters.', default="mrun")
         self.parser.add_argument('--static-rid', dest="static.rid", action='store_true', help = 'Use static RunID. Will result in overwriting of report files. Useful during script development.')
-        self.parser.add_argument('-rf', '--report-formats', dest="project.report.formats", type=report_format, metavar=('F1','F2'), default=['XML', 'HTML'], nargs='+', help='One or more report format names.') # choices=['XML', 'HTML'], 
+        self.parser.add_argument('-rf', '--report-formats', dest="report.formats", type=report_format, metavar=('F1','F2'), default=['XML', 'HTML'], nargs='+', help='One or more report format names.') # choices=['XML', 'HTML'], 
         self.parser.add_argument('--dry-run', dest="dry_run", action='store_true', help = 'Launch Arjuna, enumerate tests, but do not execute tests.')
-
-        # self.parser.add_argument('-aco', '--arjuna-ref-option', dest="aro",
-        #                          nargs=2,
-        #                          action='append',
-        #                          metavar=('option', 'value'),
-        #                          help='Arjuna Reference Option. Can pass any number of these switches as -aco x y -aco z t')
-        #
-        # self.parser.add_argument('-ato', '--arjuna-ext-option', dest="aeo",
-        #                          nargs=2,
-        #                          action='append',
-        #                          metavar=('option', 'value'),
-        #                          help='Arjuna Extended Option. Can pass any number of these switches as -aco x y -ato z t')
-        #
-        # self.parser.add_argument('-uco', '--user-ref-option', dest="uro",
-        #                          nargs=2,
-        #                          action='append',
-        #                          metavar=('option', 'value'),
-        #                          help='User Reference Option. Can pass any number of these switches as -aco x y -uco z t')
-        #
-        # self.parser.add_argument('-uto', '--user-ext-option', dest="ueo",
-        #                          nargs=2,
-        #                          action='append',
-        #                          metavar=('option', 'value'),
-        #                          help='User Extended Option. Can pass any number of these switches as -aco x y -uto z t')
-
+        self.parser.add_argument('--run-env', dest="run.env.name", type=str, default="not_set", help = 'Name of environment with its options defined in <env>.conf file in <Project Root>/config/env directory.')
+        self.parser.add_argument('--run-conf', dest="run_conf", type=str, default=None, help = 'Absolute path of a conf file to be used for this run.')
+        self.parser.add_argument('-ao', '--arjuna-option', dest="ao",
+                                 nargs=2,
+                                 action='append',
+                                 metavar=('option', 'value'),
+                                 help='Arjuna Option. Can pass any number of these switches.')
+        self.parser.add_argument('-uo', '--user-option', dest="uo",
+                                 nargs=2,
+                                 action='append',
+                                 metavar=('option', 'value'),
+                                 help='User Option. Can pass any number of these switches.')
     def process(self, arg_dict):
         pass
 
@@ -105,7 +92,7 @@ class PickersParser(Parser):
     def __init__(self):
         super().__init__()
         self.parser = argparse.ArgumentParser(add_help=False)
-        self.parser.add_argument('-im', '--ignore-modules', dest="imodules", metavar=('M1','M2'), default=None, nargs='+', help='One or more names/patterns for including test modules.')
+        self.parser.add_argument('-im', '--include-modules', dest="imodules", metavar=('M1','M2'), default=None, nargs='+', help='One or more names/patterns for including test modules.')
         self.parser.add_argument('-em', '--exclude-modules', dest="emodules", metavar=('M1','M2'), default=None, nargs='+', help='One or more names/patterns for excluding test modules.')
         # self.parser.add_argument('-cc', '--cclasses', dest="cclasses", metavar=('C1','C2'), default=None, nargs='+', help='One or more names/patterns for considering test classes.')
         # self.parser.add_argument('-ic', '--iclasses', dest="iclasses", metavar=('C1','C2'), default=None, nargs='+', help='One or more names/patterns for ignoring test classes.')
